@@ -4,14 +4,14 @@ from ansiblelint.runner import Runner
 
 def test_task_hook_import_playbook(default_rules_collection):
     """Assures import_playbook includes are recognized."""
-    playbook_path = 'test/playbook-import/playbook_parent.yml'
-    runner = Runner(default_rules_collection, playbook_path, [], [], [])
+    playbook_path = 'examples/playbooks/playbook-parent.yml'
+    runner = Runner(playbook_path, rules=default_rules_collection)
     results = runner.run()
 
     results_text = str(results)
-    assert len(runner.playbooks) == 2
+    assert len(runner.lintables) == 2
     assert len(results) == 2
     # Assures we detected the issues from imported playbook
     assert 'Commands should not change things' in results_text
-    assert '502' in results_text
+    assert 'unnamed-task' in results_text
     assert 'All tasks should be named' in results_text
